@@ -3,7 +3,7 @@
 namespace xs {
 
 HV* xs::Typemap<std::error_code>::stash() {
-    static PERL_THREAD_LOCAL HV* hv = gv_stashpvs("XS::STL::ErrorCode", GV_ADD);
+    static PERL_ITHREADS_LOCAL HV* hv = gv_stashpvs("XS::STL::ErrorCode", GV_ADD);
     return hv;
 }
 
